@@ -1,5 +1,4 @@
 import os
-import sys
 import yaml
 import logging
 import subprocess
@@ -16,10 +15,10 @@ class network3_perseus():
 
     def configure_device(self):
         self.get_file_from_hedera()
-        self.add_file_to_hedera("PRE-CHANGE STATE")
-        self.pre_change=self.capture_state()
+        #self.add_file_to_hedera("PRE-CHANGE STATE")
+        #self.pre_change=self.capture_state()
         self.push_config(self.yaml_contents)
-        self.post_change=self.capture_state()
+        #self.post_change=self.capture_state()
 
     def get_file_from_hedera(self):
         client = Client.forTestnet()
@@ -28,7 +27,6 @@ class network3_perseus():
         hedera_fileId = FileId.fromString(self.fileId)
         contents = query.setFileId(hedera_fileId).execute(client)
         self.yaml_contents = yaml.safe_load(contents.toStringUtf8())
-        return self.yaml_contents
 
     def capture_state(self):
         self.output = subprocess.run(["python", "call_cli.py", "show running-config"], capture_output=True)
@@ -42,11 +40,10 @@ class network3_perseus():
         print("File size according to `FileInfoQuery`: ", info.size)
 
     def push_config(self,yaml_contents):
-        print(sys.path)
-        env = Environment(loader=PackageLoader("network3_perseus", "src/templates"))
+        env = Environment(loader=PackageLoader("network3_perseus", "templates"))
         autoescape=select_autoescape()
         intended_config_template = env.get_template('intended_config.j2')
-        rendered_intended_config = intended_config_template.render(yaml_contents)
+        rendered_intended_config = intended_config_template.render(self.yaml_contents)
         subprocess.run(["python", "cli_configure.py", rendered_intended_config])
 
     def add_file_to_hedera(self, raw_json):
